@@ -17,8 +17,10 @@ FXDEFMAP(ArchInputDialog) ArchInputDialogMap[] =
 {
     FXMAPFUNC(SEL_KEYPRESS, 0, ArchInputDialog::onCmdKeyPress),
     FXMAPFUNC(SEL_COMMAND, ArchInputDialog::ID_BROWSE_PATH, ArchInputDialog::onCmdBrowsePath),
-    FXMAPFUNCS(SEL_COMMAND, ArchInputDialog::ID_FORMAT_TAR_GZ, ArchInputDialog::ID_FORMAT_Z, ArchInputDialog::onCmdOption),
-    FXMAPFUNCS(SEL_UPDATE, ArchInputDialog::ID_FORMAT_TAR_GZ, ArchInputDialog::ID_FORMAT_Z, ArchInputDialog::onUpdOption),
+    FXMAPFUNCS(SEL_COMMAND, ArchInputDialog::ID_FORMAT_TAR_GZ, ArchInputDialog::ID_FORMAT_Z,
+               ArchInputDialog::onCmdOption),
+    FXMAPFUNCS(SEL_UPDATE, ArchInputDialog::ID_FORMAT_TAR_GZ, ArchInputDialog::ID_FORMAT_Z,
+               ArchInputDialog::onUpdOption),
 };
 
 
@@ -30,13 +32,14 @@ ArchInputDialog::ArchInputDialog(FXWindow* win, FXString inp) :
     DialogBox(win, _("Add To Archive"), DECOR_TITLE | DECOR_BORDER | DECOR_STRETCHABLE | DECOR_MAXIMIZE | DECOR_CLOSE)
 {
     // Buttons
-    FXHorizontalFrame* buttons = new FXHorizontalFrame(this, PACK_UNIFORM_WIDTH | LAYOUT_SIDE_BOTTOM | LAYOUT_FILL_X, 0, 0, 0, 0, 10, 10, 5, 5);
+    FXHorizontalFrame* buttons = new FXHorizontalFrame(this, PACK_UNIFORM_WIDTH | LAYOUT_SIDE_BOTTOM | LAYOUT_FILL_X,
+                                                       0, 0, 0, 0, 10, 10, 5, 5);
 
     // Accept
-    new FXButton(buttons, _("&Accept"), NULL, this, ID_ACCEPT, FRAME_RAISED | FRAME_THICK | LAYOUT_RIGHT, 0, 0, 0, 0, 20, 20);
+    new FXButton(buttons, _("&Accept"), NULL, this, ID_ACCEPT, FRAME_GROOVE | LAYOUT_RIGHT, 0, 0, 0, 0, 20, 20);
 
     // Cancel
-    new FXButton(buttons, _("&Cancel"), NULL, this, ID_CANCEL, FRAME_RAISED | FRAME_THICK | LAYOUT_RIGHT, 0, 0, 0, 0, 20, 20);
+    new FXButton(buttons, _("&Cancel"), NULL, this, ID_CANCEL, FRAME_GROOVE | LAYOUT_RIGHT, 0, 0, 0, 0, 20, 20);
 
     // Vertical frame
     FXVerticalFrame* contents = new FXVerticalFrame(this, LAYOUT_SIDE_TOP | FRAME_NONE | LAYOUT_FILL_X | LAYOUT_FILL_Y);
@@ -44,37 +47,53 @@ ArchInputDialog::ArchInputDialog(FXWindow* win, FXString inp) :
     // Icon and message line
     FXMatrix* matrix = new FXMatrix(contents, 2, MATRIX_BY_COLUMNS | LAYOUT_SIDE_TOP | LAYOUT_FILL_X | LAYOUT_FILL_Y);
     new FXLabel(matrix, "", bigarchaddicon, LAYOUT_LEFT);
-    new FXLabel(matrix, _("New archive name:"), NULL, JUSTIFY_LEFT | LAYOUT_CENTER_Y | LAYOUT_FILL_COLUMN | LAYOUT_FILL_ROW);
+    new FXLabel(matrix, _("New archive name:"), NULL,
+                JUSTIFY_LEFT | LAYOUT_CENTER_Y | LAYOUT_FILL_COLUMN | LAYOUT_FILL_ROW);
 
     // Label and input field
     FXMatrix* matrix3 = new FXMatrix(contents, 2, MATRIX_BY_COLUMNS | LAYOUT_SIDE_TOP | LAYOUT_FILL_X | LAYOUT_FILL_Y);
-    input = new FXTextField(matrix3, 40, 0, 0, LAYOUT_CENTER_Y | LAYOUT_CENTER_X | FRAME_SUNKEN | FRAME_THICK | LAYOUT_FILL_COLUMN | LAYOUT_FILL_ROW | LAYOUT_FILL_X);
+    input = new FXTextField(matrix3, 40, 0, 0,
+                            LAYOUT_CENTER_Y | LAYOUT_CENTER_X | TEXTFIELD_NORMAL | LAYOUT_FILL_COLUMN |
+                            LAYOUT_FILL_ROW | LAYOUT_FILL_X);
     input->setText(inp);
-    if (!isUtf8(inp.text(), inp.length()))
+    if (!xf_isutf8(inp.text(), inp.length()))
     {
-        new FXLabel(contents, _("=> Warning: file name is not UTF-8 encoded!"), NULL, LAYOUT_LEFT | LAYOUT_CENTER_Y | LAYOUT_FILL_ROW);
+        new FXLabel(contents, _("=> Warning: file name is not UTF-8 encoded!"), NULL,
+                    LAYOUT_LEFT | LAYOUT_CENTER_Y | LAYOUT_FILL_ROW);
     }
-    new FXButton(matrix3, _("\tSelect destination..."), filedialogicon, this, ID_BROWSE_PATH, FRAME_RAISED | FRAME_THICK | LAYOUT_RIGHT | LAYOUT_CENTER_Y, 0, 0, 0, 0, 20, 20);
+    new FXButton(matrix3, _("\tSelect destination..."), minifiledialogicon, this, ID_BROWSE_PATH,
+                 FRAME_GROOVE | LAYOUT_RIGHT |
+                 LAYOUT_CENTER_Y, 0, 0, 0, 0, 20, 20);
 
     // Select archive format
     FXMatrix* matrix4 = new FXMatrix(contents, 2, MATRIX_BY_COLUMNS | LAYOUT_SIDE_TOP | LAYOUT_FILL_X | LAYOUT_FILL_Y);
     new FXLabel(matrix4, _("Format:"), NULL, LAYOUT_LEFT | LAYOUT_CENTER_Y | LAYOUT_FILL_ROW);
     popup = new FXPopup(this);
-    option_tgz = new FXOption(popup, _("tar.gz\tArchive format is tar.gz"), NULL, this, ID_FORMAT_TAR_GZ, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
-    option_zip = new FXOption(popup, _("zip\tArchive format is zip"), NULL, this, ID_FORMAT_ZIP, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
-    option_7zip = new FXOption(popup, _("7z\tArchive format is 7z"), NULL, this, ID_FORMAT_7ZIP, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
-    option_rar = new FXOption(popup, _("rar\tArchive format is rar"), NULL, this, ID_FORMAT_RAR, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
-    option_tbz2 = new FXOption(popup, _("tar.bz2\tArchive format is tar.bz2"), NULL, this, ID_FORMAT_TAR_BZ2, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
-    option_txz = new FXOption(popup, _("tar.xz\tArchive format is tar.xz"), NULL, this, ID_FORMAT_TAR_XZ, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
-    option_tzst = new FXOption(popup, _("tar.zst\tArchive format is tar.zst"), NULL, this, ID_FORMAT_TAR_ZST, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
-    option_tar = new FXOption(popup, _("tar\tArchive format is tar"), NULL, this, ID_FORMAT_TAR, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
-    option_taz = new FXOption(popup, _("tar.Z\tArchive format is tar.Z"), NULL, this, ID_FORMAT_TAR_Z, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
-    option_gz = new FXOption(popup, _("gz\tArchive format is gz"), NULL, this, ID_FORMAT_GZ, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
-    option_bz2 = new FXOption(popup, _("bz2\tArchive format is bz2"), NULL, this, ID_FORMAT_BZ2, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
-    option_xz = new FXOption(popup, _("xz\tArchive format is xz"), NULL, this, ID_FORMAT_XZ, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
-    option_zst = new FXOption(popup, _("zst\tArchive format is zst"), NULL, this, ID_FORMAT_ZST, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
-    option_z = new FXOption(popup, _("Z\tArchive format is Z"), NULL, this, ID_FORMAT_Z, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
-    optionmenu = new FXOptionMenu(matrix4, popup, LAYOUT_TOP | FRAME_RAISED | FRAME_THICK | JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
+    option_tgz = new FXOption(popup, _("tar.gz\tArchive format tar.gz"), NULL, this, ID_FORMAT_TAR_GZ,
+                              JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
+    option_zip = new FXOption(popup, _("zip\tArchive format zip"), NULL, this, ID_FORMAT_ZIP,
+                              JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
+    option_7zip = new FXOption(popup, _("7z\tArchive format 7z"), NULL, this, ID_FORMAT_7ZIP,
+                               JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
+    option_rar = new FXOption(popup, _("rar\tArchive format rar"), NULL, this, ID_FORMAT_RAR,
+                              JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
+    option_tbz2 = new FXOption(popup, _("tar.bz2\tArchive format tar.bz2"), NULL, this, ID_FORMAT_TAR_BZ2,
+                               JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
+    option_txz = new FXOption(popup, _("tar.xz\tArchive format tar.xz"), NULL, this, ID_FORMAT_TAR_XZ,
+                              JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
+    option_tzst = new FXOption(popup, _("tar.zst\tArchive format tar.zst"), NULL, this, ID_FORMAT_TAR_ZST,
+                               JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
+    option_tar = new FXOption(popup, _("tar\tArchive format tar"), NULL, this, ID_FORMAT_TAR,
+                              JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
+    option_gz = new FXOption(popup, _("gz\tArchive format gz"), NULL, this, ID_FORMAT_GZ,
+                             JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
+    option_bz2 = new FXOption(popup, _("bz2\tArchive format bz2"), NULL, this, ID_FORMAT_BZ2,
+                              JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
+    option_xz = new FXOption(popup, _("xz\tArchive format xz"), NULL, this, ID_FORMAT_XZ,
+                             JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
+    option_zst = new FXOption(popup, _("zst\tArchive format zst"), NULL, this, ID_FORMAT_ZST,
+                              JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
+    optionmenu = new FXOptionMenu(matrix4, popup, LAYOUT_TOP | FRAME_GROOVE | JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
 }
 
 
@@ -99,22 +118,22 @@ long ArchInputDialog::onCmdKeyPress(FXObject* sender, FXSelector sel, void* ptr)
     {
     case KEY_Escape:
         handle(this, FXSEL(SEL_COMMAND, ID_CANCEL), NULL);
-        return(1);
+        return 1;
 
     case KEY_KP_Enter:
     case KEY_Return:
         handle(this, FXSEL(SEL_COMMAND, ID_ACCEPT), NULL);
-        return(1);
+        return 1;
 
     default:
         FXTopWindow::onKeyPress(sender, sel, ptr);
-        return(1);
+        return 1;
     }
-    return(0);
+    return 0;
 }
 
 
-long ArchInputDialog::onCmdBrowsePath(FXObject* o, FXSelector s, void* p)
+long ArchInputDialog::onCmdBrowsePath(FXObject* sender, FXSelector sel, void* ptr)
 {
     // File dialog
     FileDialog browse(this, _("Select a destination folder"));
@@ -135,7 +154,7 @@ long ArchInputDialog::onCmdBrowsePath(FXObject* o, FXSelector s, void* p)
         input->setText(path + PATHSEPSTRING + archname);
     }
 
-    return(1);
+    return 1;
 }
 
 
@@ -179,7 +198,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
         else if ((ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2") || (ext1 == "zst")
-              || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
+                 || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".tar.gz";
@@ -203,7 +222,6 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
     }
-
     else if (FXSELID(sel) == ID_FORMAT_TAR_BZ2)
     {
         // Handle different archive formats
@@ -236,7 +254,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
         else if ((ext1 == "tgz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2") || (ext1 == "zst")
-              || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
+                 || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".tar.bz2";
@@ -260,7 +278,6 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
     }
-
     else if (FXSELID(sel) == ID_FORMAT_TAR_XZ)
     {
         // Handle different archive formats
@@ -293,7 +310,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
         else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "taz") || (ext1 == "bz2") || (ext1 == "zst")
-              || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
+                 || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".tar.xz";
@@ -317,7 +334,6 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
     }
-
     else if (FXSELID(sel) == ID_FORMAT_TAR_ZST)
     {
         // Handle different archive formats
@@ -350,7 +366,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
         else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2")
-              || (ext1 == "zst") || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
+                 || (ext1 == "zst") || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".tar.zst";
@@ -374,12 +390,11 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
     }
-
     else if (FXSELID(sel) == ID_FORMAT_TAR)
     {
         // Handle different archive formats
         if ((ext1 == "tar") && (ext2 != "tar.gz") && (ext2 != "tar.bz2") && (ext2 != "tar.z")
-         && (ext2 != "tar.xz") && (ext2 != "tar.zst"))
+            && (ext2 != "tar.xz") && (ext2 != "tar.zst"))
         {
             input->setText(str);
         }
@@ -408,7 +423,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
         else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2")
-              || (ext1 == "zst") || (ext1 == "zip") || (ext1 == "rar"))
+                 || (ext1 == "zst") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".tar";
@@ -432,7 +447,6 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
     }
-
     else if (FXSELID(sel) == ID_FORMAT_TAR_Z)
     {
         // Handle different archive formats
@@ -459,7 +473,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
         else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "bz2") || (ext1 == "zst")
-              || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
+                 || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".tar.Z";
@@ -483,7 +497,6 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
     }
-
     else if (FXSELID(sel) == ID_FORMAT_GZ)
     {
         // Handle different archive formats
@@ -516,7 +529,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
         else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2")
-              || (ext1 == "zst") || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
+                 || (ext1 == "zst") || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".gz";
@@ -540,7 +553,6 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
     }
-
     else if (FXSELID(sel) == ID_FORMAT_XZ)
     {
         // Handle different archive formats
@@ -573,7 +585,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
         else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2")
-              || (ext1 == "zst") || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
+                 || (ext1 == "zst") || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".xz";
@@ -597,7 +609,6 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
     }
-
     else if (FXSELID(sel) == ID_FORMAT_BZ2)
     {
         // Handle different archive formats
@@ -631,7 +642,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
         else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "zst")
-              || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
+                 || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".bz2";
@@ -655,7 +666,6 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
     }
-
     else if (FXSELID(sel) == ID_FORMAT_ZST)
     {
         // Handle different archive formats
@@ -689,7 +699,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
         else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2")
-              || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
+                 || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".zst";
@@ -713,7 +723,6 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
     }
-
     else if (FXSELID(sel) == ID_FORMAT_Z)
     {
         // Handle different archive formats
@@ -746,7 +755,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
         else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2")
-              || (ext1 == "zst") || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
+                 || (ext1 == "zst") || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".Z";
@@ -764,7 +773,6 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
     }
-
     else if (FXSELID(sel) == ID_FORMAT_ZIP)
     {
         // Handle different archive formats
@@ -797,7 +805,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
         else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2")
-              || (ext1 == "zst") || (ext1 == "tar") || (ext1 == "rar"))
+                 || (ext1 == "zst") || (ext1 == "tar") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".zip";
@@ -821,7 +829,6 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
     }
-
     else if (FXSELID(sel) == ID_FORMAT_7ZIP)
     {
         // Handle different archive formats
@@ -854,7 +861,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
         else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2")
-              || (ext1 == "zst") || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
+                 || (ext1 == "zst") || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".7z";
@@ -878,7 +885,6 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
     }
-    
     else if (FXSELID(sel) == ID_FORMAT_RAR)
     {
         // Handle different archive formats
@@ -911,7 +917,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
         else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2")
-              || (ext1 == "zst") || (ext1 == "tar") || (ext1 == "zip"))
+                 || (ext1 == "zst") || (ext1 == "tar") || (ext1 == "zip"))
         {
             str = str.left(str.length() - 4);
             str = str + ".rar";
@@ -936,7 +942,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
         }
     }
 
-    return(1);
+    return 1;
 }
 
 
@@ -1010,5 +1016,5 @@ long ArchInputDialog::onUpdOption(FXObject*, FXSelector sel, void*)
         optionmenu->setCurrent(option_tgz);
     }
 
-    return(1);
+    return 1;
 }
