@@ -18,22 +18,24 @@ class BrowseInputDialog : public DialogBox
 {
     FXDECLARE(BrowseInputDialog)
 protected:
-    FXTextField*       input;
-    TextLabel*         msg;
-    FXLabel*           iconlabel;
-    FXHorizontalFrame* checkbutton;
-    FXuint browsetype;
+    FXTextField* input = NULL;
+    TextLabel* msg = NULL;
+    FXLabel* iconlabel = NULL;
+    FXHorizontalFrame* checkbutton = NULL;
+    FXuint browsetype = 0;
     FXString initialdir;
 private:
-    BrowseInputDialog() : input(NULL), msg(NULL), iconlabel(NULL), checkbutton(NULL), browsetype(0)
-    {}
+    BrowseInputDialog()
+    {
+    }
 public:
     enum
     {
         ID_BROWSE_PATH=DialogBox::ID_LAST,
         ID_LAST
     };
-    BrowseInputDialog(FXWindow*, FXString, FXString, FXString, FXString label = "", FXIcon* ic = NULL, FXuint browse = BROWSE_INPUT_FILE, FXbool option = false, FXString = FXString::null);
+    BrowseInputDialog(FXWindow*, FXString, FXString, FXString, FXString label = "", FXIcon* ic = NULL,
+                      FXuint browse = BROWSE_INPUT_FILE, FXbool option = false, FXString = FXString::null);
     virtual void create();
 
     virtual ~BrowseInputDialog();
