@@ -18,10 +18,6 @@
 #define ICONNAMELEN     256
 
 
-// Icon scale factor
-extern double scalefrac;
-
-
 // Object implementation
 FXIMPLEMENT(IconDict, FXDict, NULL, 0)
 
@@ -35,22 +31,26 @@ IconDict::IconDict(FXApp* a, const FXString& p) : path(p)
 {
     app = a;
     source = new FXIconSource(a);
+
+    // Fractional scaling factor
+    FXint res = getApp()->reg().readUnsignedEntry("SETTINGS", "screenres", 100);
+    scalefrac = FXMAX(1.0, res / 100.0);
 }
 
 
 // Search for the icon name along the search path, and try to load it
 void* IconDict::createData(const void* ptr)
 {
-	// Load icon
-	FXIcon* icon = source->loadIconFile(FXPath::search(path, (const char*)ptr));
-	
-	// Scale icon
-	if (icon)
-	{
-		icon->scale(scalefrac*icon->getWidth(), scalefrac*icon->getHeight());
-	}
+    // Load icon
+    FXIcon* icon = source->loadIconFile(FXPath::search(path, (const char*)ptr));
 
-    return(icon);
+    // Scale icon
+    if (icon)
+    {
+        icon->scale(scalefrac * icon->getWidth(), scalefrac * icon->getHeight());
+    }
+
+    return icon;
 }
 
 
@@ -103,7 +103,8 @@ FileDict::FileDict(FXApp* a) : app(a), settings(&a->reg())
 {
     // Set icon path if it exists, otherwise set icon path to default
     FXString iconpath = settings->readStringEntry("SETTINGS", "iconpath", DEFAULTICONPATH);
-    if ( !existFile(iconpath) )
+
+    if (!xf_existfile(iconpath))
     {
         iconpath = DEFAULTICONPATH;
     }
@@ -116,7 +117,8 @@ FileDict::FileDict(FXApp* a, FXSettings* db) : app(a), settings(db)
 {
     // Set icon path if it exists, otherwise set icon path to default
     FXString iconpath = settings->readStringEntry("SETTINGS", "iconpath", DEFAULTICONPATH);
-    if ( !existFile(iconpath) )
+
+    if (!xf_existfile(iconpath))
     {
         iconpath = DEFAULTICONPATH;
     }
@@ -128,7 +130,7 @@ FileDict::FileDict(FXApp* a, FXSettings* db) : app(a), settings(db)
 void* FileDict::createData(const void* ptr)
 {
     const char* p = (const char*)ptr;
-    char*       q;
+    char* q;
     char command[COMMANDLEN];
     char extension[EXTENSIONLEN];
     char mimetype[MIMETYPELEN];
@@ -136,14 +138,15 @@ void* FileDict::createData(const void* ptr)
     char bignameopen[ICONNAMELEN];
     char mininame[ICONNAMELEN];
     char mininameopen[ICONNAMELEN];
-    FileAssoc*           fileassoc;
+    FileAssoc* fileassoc;
 
     // Make association record
     fileassoc = new FileAssoc;
 
     // Parse command
     for (q = command; *p && *p != ';' && q < command + COMMANDLEN - 1; *q++ = *p++)
-    {}
+    {
+    }
     *q = '\0';
 
     // Skip section separator
@@ -154,7 +157,8 @@ void* FileDict::createData(const void* ptr)
 
     // Parse extension type
     for (q = extension; *p && *p != ';' && q < extension + EXTENSIONLEN - 1; *q++ = *p++)
-    {}
+    {
+    }
     *q = '\0';
 
     // Skip section separator
@@ -165,7 +169,8 @@ void* FileDict::createData(const void* ptr)
 
     // Parse big icon name
     for (q = bigname; *p && *p != ';' && *p != ':' && q < bigname + ICONNAMELEN - 1; *q++ = *p++)
-    {}
+    {
+    }
     *q = '\0';
 
     // Skip icon separator
@@ -176,7 +181,8 @@ void* FileDict::createData(const void* ptr)
 
     // Parse big open icon name
     for (q = bignameopen; *p && *p != ';' && q < bignameopen + ICONNAMELEN - 1; *q++ = *p++)
-    {}
+    {
+    }
     *q = '\0';
 
     // Skip section separator
@@ -187,7 +193,8 @@ void* FileDict::createData(const void* ptr)
 
     // Parse mini icon name
     for (q = mininame; *p && *p != ';' && *p != ':' && q < mininame + ICONNAMELEN - 1; *q++ = *p++)
-    {}
+    {
+    }
     *q = '\0';
 
     // Skip icon separator
@@ -198,7 +205,8 @@ void* FileDict::createData(const void* ptr)
 
     // Parse mini open icon name
     for (q = mininameopen; *p && *p != ';' && q < mininameopen + ICONNAMELEN - 1; *q++ = *p++)
-    {}
+    {
+    }
     *q = '\0';
 
     // Skip section separator
@@ -209,7 +217,8 @@ void* FileDict::createData(const void* ptr)
 
     // Parse mime type
     for (q = mimetype; *p && *p != ';' && q < mimetype + MIMETYPELEN - 1; *q++ = *p++)
-    {}
+    {
+    }
     *q = '\0';
 
     // Initialize association data
@@ -244,7 +253,7 @@ void* FileDict::createData(const void* ptr)
     }
 
     // Return the binding
-    return(fileassoc);
+    return fileassoc;
 }
 
 
@@ -269,7 +278,7 @@ void FileDict::setIconPath(const FXString& path)
 // Return current icon search path
 FXString FileDict::getIconPath() const
 {
-    return(icons->getIconPath());
+    return icons->getIconPath();
 }
 
 
@@ -280,7 +289,7 @@ FileAssoc* FileDict::replace(const char* ext, const char* str)
     settings->writeStringEntry("FILETYPES", ext, str);
 
     // Replace record
-    return((FileAssoc*)FXDict::replace(ext, str));
+    return (FileAssoc*)FXDict::replace(ext, str);
 }
 
 
@@ -293,7 +302,7 @@ FileAssoc* FileDict::remove(const char* ext)
     // Remove record
     FXDict::remove(ext);
 
-    return(NULL);
+    return NULL;
 }
 
 
@@ -301,19 +310,19 @@ FileAssoc* FileDict::remove(const char* ext)
 FileAssoc* FileDict::associate(const char* key)
 {
     const char* association;
-    FileAssoc*  record;
+    FileAssoc* record;
     char lowkey[MAXPATHLEN];
 
     // Convert the association key to lower case
     // Uses these functions because they seem to be faster than FXString
-    strlcpy_(lowkey, key, strlen(key) + 1);
-    strlow(lowkey);
+    xf_strlcpy(lowkey, key, strlen(key) + 1);
+    xf_tolowercase(lowkey);
 
     // See if we have an existing record already and stores the key extension
     if ((record = find(lowkey)) != NULL)
     {
         record->key = lowkey;
-        return(record);
+        return record;
     }
 
     // See if this entry is known in FILETYPES
@@ -324,11 +333,11 @@ FileAssoc* FileDict::associate(const char* key)
     {
         record = (FileAssoc*)FXDict::insert(lowkey, association);
         record->key = lowkey;
-        return(record);
+        return record;
     }
 
     // Not a known file type
-    return(NULL);
+    return NULL;
 }
 
 
@@ -337,7 +346,7 @@ FileAssoc* FileDict::findFileBinding(const char* pathname)
 {
     const char* filename = pathname;
     const char* p = pathname;
-    FileAssoc*  record;
+    FileAssoc* record;
 
     while (*p)
     {
@@ -350,14 +359,14 @@ FileAssoc* FileDict::findFileBinding(const char* pathname)
 
     if (strlen(filename) == 0)
     {
-        return(associate(defaultFileBinding));
+        return associate(defaultFileBinding);
     }
 
     record = associate(filename);
 
     if (record)
     {
-        return(record);
+        return record;
     }
 
     filename = strchr(filename, '.');
@@ -370,11 +379,11 @@ FileAssoc* FileDict::findFileBinding(const char* pathname)
         }
         if (record)
         {
-            return(record);
+            return record;
         }
         filename = strchr(filename + 1, '.');
     }
-    return(associate(defaultFileBinding));
+    return associate(defaultFileBinding);
 }
 
 
@@ -382,14 +391,14 @@ FileAssoc* FileDict::findFileBinding(const char* pathname)
 FileAssoc* FileDict::findDirBinding(const char* pathname)
 {
     const char* path = pathname;
-    FileAssoc*  record;
+    FileAssoc* record;
 
     while (*path)
     {
         record = associate(path);
         if (record)
         {
-            return(record);
+            return record;
         }
         path++;
         while (*path && !ISPATHSEP(*path))
@@ -397,14 +406,14 @@ FileAssoc* FileDict::findDirBinding(const char* pathname)
             path++;
         }
     }
-    return(associate(defaultDirBinding));
+    return associate(defaultDirBinding);
 }
 
 
 // Find executable association from registry
 FileAssoc* FileDict::findExecBinding(const char* pathname)
 {
-    return(associate(defaultExecBinding));
+    return associate(defaultExecBinding);
 }
 
 
