@@ -1,6 +1,7 @@
 #ifndef FILELIST_H
 #define FILELIST_H
 
+#include "xfedefs.h"
 #include "StringList.h"
 #include "IconList.h"
 
@@ -9,12 +10,14 @@ struct FileAssoc;
 class FileDict;
 class FileList;
 
-// File List options (prefixed by underscore to avoid conflict with the FOX library)
+// File List options
 enum
 {
-    _FILELIST_SHOWHIDDEN   = 0x04000000, // Show hidden files or directories
-    _FILELIST_SHOWDIRS     = 0x08000000, // Show only directories
-    _FILELIST_SEARCH       = 0x10000000, // File list is a search list (must be the same value as in IconList)
+    /* These options are already declared in FXFileList.h
+    FILELIST_SHOWHIDDEN    = 0x04000000,          // Show hidden files or directories
+    FILELIST_SHOWDIRS      = 0x08000000,          // Show only directories
+    */
+    FILELIST_SEARCH        = 0x10000000,          // File list is a search list (must be the same value as in IconList)
 };
 
 // File item
@@ -24,96 +27,98 @@ class FXAPI FileItem : public IconItem
     friend class FileList;
     friend class SearchPanel;
 protected:
-    FileAssoc* assoc;                       // File association record
-    FileItem*  link;                        // Link to next item
-    FXulong size;                           // File size
-    FXTime date;                            // File date (mtime)
-    FXTime cdate;                           // Changed date (ctime)
-    FXTime deldate;                         // Deletion date
+    FileAssoc* assoc = NULL;                       // File association record
+    FileItem* link = NULL;                         // Link to next item
+    FXulong size = 0;                              // File size
+    FXTime date = 0;                               // File date (mtime)
+    FXTime cdate = 0;                              // Changed date (ctime)
+    FXTime deldate = 0;                            // Deletion date
 protected:
-    FileItem() : assoc(NULL), link(NULL), size(0), date(0), cdate(0), deldate(0)
-    {}
+    FileItem()
+    {
+    }
 protected:
     enum
     {
-        FOLDER     = 64,                        // Directory item
-        EXECUTABLE = 128,                       // Executable item
-        SYMLINK    = 256,                       // Symbolic linked item
-        CHARDEV    = 512,                       // Character special item
-        BLOCKDEV   = 1024,                      // Block special item
-        FIFO       = 2048,                      // FIFO item
-        SOCK       = 4096                       // Socket item
+        FOLDER       = 64,                         // Directory item
+        EXECUTABLE   = 128,                        // Executable item
+        SYMLINK      = 256,                        // Symbolic linked item
+        CHARDEV      = 512,                        // Character special item
+        BLOCKDEV     = 1024,                       // Block special item
+        FIFO         = 2048,                       // FIFO item
+        SOCK         = 4096                        // Socket item
     };
 public:
     // Constructor
-    FileItem(const FXString& text, FXIcon* bi = NULL, FXIcon* mi = NULL, void* ptr = NULL) : IconItem(text, bi, mi, ptr), assoc(NULL),
-        link(NULL), size(0), date(0), cdate(0), deldate(0)
-    {}
+    FileItem(FXApp* a, const FXString& text, FXIcon* bi = NULL, FXIcon* mi = NULL, void* ptr = NULL) :
+        IconItem(a, text, bi, mi, ptr), assoc(NULL), link(NULL), size(0), date(0), cdate(0), deldate(0)
+    {
+    }
 
     // Return true if this is a file item
     FXbool isFile() const
     {
-        return((state & (FOLDER | BLOCKDEV | CHARDEV | FIFO | SOCK)) == 0);
+        return (state & (FOLDER | BLOCKDEV | CHARDEV | FIFO | SOCK)) == 0;
     }
 
     // Return true if this is a directory item
     FXbool isDirectory() const
     {
-        return((state & FOLDER) != 0);
+        return (state & FOLDER) != 0;
     }
 
     // Return true if this is an executable item
     FXbool isExecutable() const
     {
-        return((state & EXECUTABLE) != 0);
+        return (state & EXECUTABLE) != 0;
     }
 
     // Return true if this is a symbolic link item
     FXbool isSymlink() const
     {
-        return((state & SYMLINK) != 0);
+        return (state & SYMLINK) != 0;
     }
 
     // Return true if this is a character device item
     FXbool isChardev() const
     {
-        return((state & CHARDEV) != 0);
+        return (state & CHARDEV) != 0;
     }
 
     // Return true if this is a block device item
     FXbool isBlockdev() const
     {
-        return((state & BLOCKDEV) != 0);
+        return (state & BLOCKDEV) != 0;
     }
 
     // Return true if this is an FIFO item
     FXbool isFifo() const
     {
-        return((state & FIFO) != 0);
+        return (state & FIFO) != 0;
     }
 
     // Return true if this is a socket
     FXbool isSocket() const
     {
-        return((state & SOCK) != 0);
+        return (state & SOCK) != 0;
     }
 
     // Return the file-association object for this item
     FileAssoc* getAssoc() const
     {
-        return(assoc);
+        return assoc;
     }
 
     // Return the file size for this item
     FXulong getSize() const
     {
-        return(size);
+        return size;
     }
 
     // Return the date for this item
     FXTime getDate() const
     {
-        return(date);
+        return date;
     }
 };
 
@@ -123,35 +128,55 @@ class FXAPI FileList : public IconList
 {
     FXDECLARE(FileList)
 protected:
-    FileItem*    list;               // File item list
-    int prevIndex;
-    FXString directory;              // Current directory
-    FXString orgdirectory;           // Original directory
-    FXString dropdirectory;          // Drop directory
-    FXDragAction dropaction;         // Drop action
-    FXString dragfiles;              // Dragged files
-    FileDict*    associations;       // Association table
-    FXString pattern;                // Pattern of file names
-    FXuint matchmode;                // File wildcard match mode
-    FXTime timestamp;                // Time when last refreshed
-    FXuint counter;                  // Refresh counter
-    FXbool allowrefresh;             // Allow or disallow periodic refresh
-    FXbool displaythumbnails;        // Display thumbnails
-    FXString trashfileslocation;     // Location of the trash files directory
-    FXString trashinfolocation;      // Location of the trash info directory
-    FXbool dirsfirst;                // Sort directories first
-    int deldatesize;
-    int origpathsize;
-    FXWindow*    focuswindow;          // Window used to test focus
+    FileItem* list = NULL;                              // File item list
+    int prevIndex = 0;
+    FXString directory;                                 // Current directory
+    FXString orgdirectory;                              // Original directory
+    FXString dropdirectory;                             // Drop directory
+    FXDragAction dropaction;                            // Drop action
+    FXString dragfiles;                                 // Dragged files
+    FileDict* associations = NULL;                      // Association table
+    FXString pattern;                                   // Pattern of file names
+    FXuint matchmode = 0;                               // File wildcard match mode
+    FXTime timestamp = 0;                               // Time when last refreshed
+    FXuint counter = 0;                                 // Refresh counter
+    FXbool allowrefresh = false;                        // Allow or disallow periodic refresh
+    FXbool displaythumbnails = false;                   // Display thumbnails
+    FXString trashfileslocation;                        // Location of the trash files directory
+    FXString trashinfolocation;                         // Location of the trash info directory
+    FXbool dirsfirst = false;                           // Sort directories first
+    FXbool filter_folders = false;                      // Filter folders
+    double scalefrac = 1.0;                             // Icon scaling factor
+    FXuint deldate_size = 0;
+    FXuint origpath_size = 0;
+    FXWindow* focuswindow = NULL;                       // Window used to test focus
+    FXuint idCol[NMAX_COLS + 1] = { 0 };
+    FXuint nbCols = 0;
+    FXuint idColTrash[NMAX_COLS + 2] = { 0 };
+    FXuint nbColsTrash = 0;
+
+    // Static variables
+    static int name_index;                              // Index of name column (always 0)
+    static int size_index;                              // Index of size column
+    static int type_index;                              // Index of type column
+    static int ext_index;                               // Index of ext column
+    static int date_index;                              // Index of date column
+    static int user_index;                              // Index of user column
+    static int group_index;                             // Index of group column
+    static int perms_index;                             // Index of permissions column
+    static int link_index;                              // Index of link column
+    static int origpath_index;                          // Index of original path column (in trash)
+    static int deldate_index;                           // Index of deletion column (in trash)
+    static int dirname_index;                           // Index of directory path column (in search list)
+
 public:
-    StringList* backhist;              // Back history
-    StringList* forwardhist;           // Forward history
+    StringList* backhist = NULL;                        // Back history
+    StringList* forwardhist = NULL;                     // Forward history
 
 protected:
-    FileList() : list(NULL), prevIndex(0), dropaction(DRAG_MOVE), associations(NULL),
-        matchmode(0), timestamp(0), counter(0), allowrefresh(false), displaythumbnails(false), dirsfirst(false),
-        deldatesize(0), origpathsize(0), focuswindow(NULL), backhist(NULL), forwardhist(NULL)
-    {}
+    FileList()
+    {
+    }
     virtual IconItem* createItem(const FXString& text, FXIcon* big, FXIcon* mini, void* ptr);
 
     FXbool updateItems(FXbool);
@@ -185,16 +210,18 @@ public:
     long onUpdSortBySize(FXObject*, FXSelector, void*);
     long onCmdSortByExt(FXObject*, FXSelector, void*);
     long onUpdSortByExt(FXObject*, FXSelector, void*);
-    long onCmdSortByTime(FXObject*, FXSelector, void*);
-    long onUpdSortByTime(FXObject*, FXSelector, void*);
+    long onCmdSortByDate(FXObject*, FXSelector, void*);
+    long onUpdSortByDate(FXObject*, FXSelector, void*);
     long onCmdSortByUser(FXObject*, FXSelector, void*);
     long onUpdSortByUser(FXObject*, FXSelector, void*);
     long onCmdSortByGroup(FXObject*, FXSelector, void*);
     long onUpdSortByGroup(FXObject*, FXSelector, void*);
-    long onCmdSortByPerm(FXObject*, FXSelector, void*);
-    long onUpdSortByPerm(FXObject*, FXSelector, void*);
-    long onCmdSortByDeltime(FXObject*, FXSelector, void*);
-    long onUpdSortByDeltime(FXObject*, FXSelector, void*);
+    long onCmdSortByPerms(FXObject*, FXSelector, void*);
+    long onUpdSortByPerms(FXObject*, FXSelector, void*);
+    long onCmdSortByLink(FXObject*, FXSelector, void*);
+    long onUpdSortByLink(FXObject*, FXSelector, void*);
+    long onCmdSortByDeldate(FXObject*, FXSelector, void*);
+    long onUpdSortByDeldate(FXObject*, FXSelector, void*);
     long onCmdSortByOrigpath(FXObject*, FXSelector, void*);
     long onUpdSortByOrigpath(FXObject*, FXSelector, void*);
     long onCmdSortReverse(FXObject*, FXSelector, void*);
@@ -212,14 +239,16 @@ public:
     long onCmdHeader(FXObject*, FXSelector, void*);
     long onUpdHeader(FXObject*, FXSelector, void*);
     long onCmdToggleThumbnails(FXObject*, FXSelector, void*);
-    long onUpdToggleThumbnails(FXObject* sender, FXSelector, void*);
+    long onUpdToggleThumbnails(FXObject*, FXSelector, void*);
     long onCmdDirsFirst(FXObject*, FXSelector, void*);
     long onUpdDirsFirst(FXObject*, FXSelector, void*);
-    long onCmdDragCopy(FXObject* sender, FXSelector, void*);
-    long onCmdDragMove(FXObject* sender, FXSelector, void*);
-    long onCmdDragLink(FXObject* sender, FXSelector, void*);
-    long onCmdDragReject(FXObject* sender, FXSelector, void*);
-    long onUpdRefreshTimer(FXObject* sender, FXSelector, void*);
+    long onCmdDragCopy(FXObject*, FXSelector, void*);
+    long onCmdDragMove(FXObject*, FXSelector, void*);
+    long onCmdDragLink(FXObject*, FXSelector, void*);
+    long onCmdDragReject(FXObject*, FXSelector, void*);
+    long onUpdRefreshTimer(FXObject*, FXSelector, void*);
+    long onCmdCloseFilter(FXObject*, FXSelector, void*);
+
 public:
     static int compare(const IconItem*, const IconItem*, FXbool, FXbool, FXbool, FXuint);
     static int ascending(const IconItem*, const IconItem*);
@@ -236,18 +265,24 @@ public:
     static int descendingSize(const IconItem*, const IconItem*);
     static int ascendingExt(const IconItem*, const IconItem*);
     static int descendingExt(const IconItem*, const IconItem*);
-    static int ascendingTime(const IconItem*, const IconItem*);
-    static int descendingTime(const IconItem*, const IconItem*);
+    static int ascendingDate(const IconItem*, const IconItem*);
+    static int descendingDate(const IconItem*, const IconItem*);
     static int ascendingUser(const IconItem*, const IconItem*);
     static int descendingUser(const IconItem*, const IconItem*);
     static int ascendingGroup(const IconItem*, const IconItem*);
     static int descendingGroup(const IconItem*, const IconItem*);
-    static int ascendingPerm(const IconItem*, const IconItem*);
-    static int descendingPerm(const IconItem*, const IconItem*);
-    static int ascendingDeltime(const IconItem*, const IconItem*);
-    static int descendingDeltime(const IconItem*, const IconItem*);
+    static int ascendingPerms(const IconItem*, const IconItem*);
+    static int descendingPerms(const IconItem*, const IconItem*);
+    static int ascendingLink(const IconItem*, const IconItem*);
+    static int descendingLink(const IconItem*, const IconItem*);
+    static int ascendingLinkCase(const IconItem*, const IconItem*);
+    static int descendingLinkCase(const IconItem*, const IconItem*);
+    static int ascendingDeldate(const IconItem*, const IconItem*);
+    static int descendingDeldate(const IconItem*, const IconItem*);
     static int ascendingOrigpath(const IconItem*, const IconItem*);
     static int descendingOrigpath(const IconItem*, const IconItem*);
+    static int ascendingOrigpathCase(const IconItem*, const IconItem*);
+    static int descendingOrigpathCase(const IconItem*, const IconItem*);
     static int ascendingMix(const IconItem*, const IconItem*);
     static int descendingMix(const IconItem*, const IconItem*);
     static int ascendingCaseMix(const IconItem*, const IconItem*);
@@ -262,34 +297,51 @@ public:
     static int descendingSizeMix(const IconItem*, const IconItem*);
     static int ascendingExtMix(const IconItem*, const IconItem*);
     static int descendingExtMix(const IconItem*, const IconItem*);
-    static int ascendingTimeMix(const IconItem*, const IconItem*);
-    static int descendingTimeMix(const IconItem*, const IconItem*);
+    static int ascendingDateMix(const IconItem*, const IconItem*);
+    static int descendingDateMix(const IconItem*, const IconItem*);
     static int ascendingUserMix(const IconItem*, const IconItem*);
     static int descendingUserMix(const IconItem*, const IconItem*);
     static int ascendingGroupMix(const IconItem*, const IconItem*);
     static int descendingGroupMix(const IconItem*, const IconItem*);
-    static int ascendingPermMix(const IconItem*, const IconItem*);
-    static int descendingPermMix(const IconItem*, const IconItem*);
-    static int ascendingDeltimeMix(const IconItem*, const IconItem*);
-    static int descendingDeltimeMix(const IconItem*, const IconItem*);
+    static int ascendingPermsMix(const IconItem*, const IconItem*);
+    static int descendingPermsMix(const IconItem*, const IconItem*);
+    static int ascendingLinkMix(const IconItem*, const IconItem*);
+    static int descendingLinkMix(const IconItem*, const IconItem*);
+    static int ascendingLinkCaseMix(const IconItem*, const IconItem*);
+    static int descendingLinkCaseMix(const IconItem*, const IconItem*);
+    static int ascendingDeldateMix(const IconItem*, const IconItem*);
+    static int descendingDeldateMix(const IconItem*, const IconItem*);
     static int ascendingOrigpathMix(const IconItem*, const IconItem*);
     static int descendingOrigpathMix(const IconItem*, const IconItem*);
+    static int ascendingOrigpathCaseMix(const IconItem*, const IconItem*);
+    static int descendingOrigpathCaseMix(const IconItem*, const IconItem*);
+
+    int getHeaderIndex(FXuint);
+    int getHeaderSize(int);
+    void setHeaderSize(int, int);
+
+    FXString labels[NMAX_COLS + 3];
+
+    void setItemLabels(FXuint*, FXuint*, FXbool, FXString, FXString, FXString,
+                       FXString, FXString, FXString, FXString, FXString, FXString,
+                       FXString, FXString, FXString, FXString, FXString*);
 
 public:
     enum
     {
-        // Note : the order of the 10 following sort IDs must be kept
-        ID_SORT_BY_NAME=IconList::ID_LAST,
-        ID_SORT_BY_SIZE,
-        ID_SORT_BY_TYPE,
-        ID_SORT_BY_EXT,
-        ID_SORT_BY_TIME,
-        ID_SORT_BY_USER,
-        ID_SORT_BY_GROUP,
-        ID_SORT_BY_PERM,
-        ID_SORT_BY_ORIGPATH,
-        ID_SORT_BY_DELTIME,
-        ID_SORT_BY_DIRNAME,
+        // Note : the order of the 10 following column IDs must be kept
+        ID_COL_NAME = IconList::ID_LAST,
+        ID_COL_SIZE,
+        ID_COL_TYPE,
+        ID_COL_EXT,
+        ID_COL_DATE,
+        ID_COL_USER,
+        ID_COL_GROUP,
+        ID_COL_PERMS,
+        ID_COL_LINK,
+        ID_COL_ORIGPATH,
+        ID_COL_DELDATE,
+        ID_COL_DIRNAME,
         ID_SORT_REVERSE,
         ID_SORT_CASE,
         ID_DIRS_FIRST,
@@ -307,12 +359,15 @@ public:
         ID_DRAG_MOVE,
         ID_DRAG_LINK,
         ID_DRAG_REJECT,
+        ID_CLOSE_FILTER,
         ID_LAST
     };
 public:
 
     // Construct a file list
-    FileList(FXWindow* focuswin, FXComposite* p, FXObject* tgt = NULL, FXSelector sel = 0, FXbool showthumbs = false, FXuint opts = 0, int x = 0, int y = 0, int w = 0, int h = 0);
+    FileList(FXWindow*, FXComposite*, FXuint*, FXuint, FXObject* tgt = NULL, FXSelector sel = 0,
+             FXbool showthumbs = false, FXuint = 0, FXuint = 0, FXuint opts = 0,
+             int x = 0, int y = 0, int w = 0, int h = 0);
 
     // Create server-side resources
     virtual void create();
@@ -332,7 +387,7 @@ public:
     // Return current directory
     FXString getDirectory() const
     {
-        return(directory);
+        return directory;
     }
 
     // Change wildcard matching pattern
@@ -341,7 +396,19 @@ public:
     // Return wildcard pattern
     FXString getPattern() const
     {
-        return(pattern);
+        return pattern;
+    }
+
+    // Get filter folders
+    FXbool getFilterFolders(void)
+    {
+        return filter_folders;
+    }
+
+    // Toggle filter folders
+    void setFilterFolders(FXbool filt)
+    {
+        filter_folders = filt;
     }
 
     // Return true if item is a directory
@@ -368,7 +435,7 @@ public:
                 num++;
             }
         }
-        return(num);
+        return num;
     }
 
     // Get number of selected items and index of first selected item
@@ -388,7 +455,7 @@ public:
             }
         }
         (*index) = itm;
-        return(num);
+        return num;
     }
 
     // Return name of item at index
@@ -409,13 +476,13 @@ public:
     // Return wildcard matching mode
     FXuint getMatchMode() const
     {
-        return(matchmode);
+        return matchmode;
     }
 
     // Return directory first state for file name sorting
     FXbool getDirsFirst() const
     {
-        return(dirsfirst);
+        return dirsfirst;
     }
 
     // Set directory first state for file name sorting
@@ -424,10 +491,6 @@ public:
         dirsfirst = dfirst;
     }
 
-    int getHeaderSize(int index) const;
-
-    void setHeaderSize(int index, int size);
-
     // Allow or disallow periodic refresh
     void setAllowRefresh(const FXbool allow);
 
@@ -458,7 +521,19 @@ public:
     // Return file associations
     FileDict* getAssociations() const
     {
-        return(associations);
+        return associations;
+    }
+
+    // Return size of deletion date column
+    FXuint getDeldateSize(void)
+    {
+        return deldate_size;
+    }
+
+    // Return size of original path column
+    FXuint getOrigpathSize(void)
+    {
+        return origpath_size;
     }
 
 #if defined(linux)
