@@ -2,44 +2,47 @@
 #define PATHLINKER_H
 
 #include <vector>
-#include "TextLabel.h"
-#include "FileList.h"
-#include "DirPanel.h"
+
 #include "xfedefs.h"
+#include "xfeutils.h"
+#include "TextLabel.h"
+#include "DirList.h"
+#include "FileList.h"
 
 class FXAPI PathLinker : public FXHorizontalFrame
 {
     FXDECLARE(PathLinker)
 
 protected:
-    typedef std::vector<FXButton*>   vector_FXButton;
+    typedef std::vector<FXButton*> vector_FXButton;
     vector_FXButton linkButtons;
-    FXuint nbActiveButtons;
-    FXuint currentButton;
+    FXuint nbActiveButtons = 0;
+    FXuint currentButton = 0;
     FXString visitedPath;
-    TextLabel*      focusButton;
-    FXFont*         normalFont;
-    FXFont*         highlightFont;
-    FileList*       filelist;
-    DirList*        dirlist;
-    PathLinker() : nbActiveButtons(0), currentButton(0), focusButton(NULL), normalFont(NULL), highlightFont(NULL), filelist(NULL), dirlist(NULL)
-    {}
+    TextLabel* focusButton = NULL;
+    FXFont* normalFont = NULL;
+    FXFont* highlightFont = NULL;
+    FileList* filelist = NULL;
+    DirList* dirlist = NULL;
+    PathLinker()
+    {
+    }
 
 private:
     void updatePath(FXString, FXuint);
     void setText(FXuint, FXString);
 
 public:
-    enum ButtonIds
+    enum
     {
         ID_START_LINK = FXHorizontalFrame::ID_LAST,
         // Note: Place any additional id's AFTER ID_END_LINK
-        ID_END_LINK = ID_START_LINK + MAX_LINKS - 1,
+        ID_END_LINK = ID_START_LINK + NMAX_LINKS - 1,
         ID_FOCUS_BUTTON,
         ID_LAST
     };
 
-    PathLinker(FXComposite* a, FileList* flist, DirList* dlist = NULL, FXuint opts = 0);
+    PathLinker(FXComposite*, FileList*, DirList* dlist = NULL, FXuint opts = 0);
     virtual void create();
 
     virtual ~PathLinker();
