@@ -25,29 +25,25 @@
 
 // Add FOX hacks
 #include "foxhacks.cpp"
-#include "clearlooks.cpp"
+#include "moderncontrols.cpp"
 
 
 // Global variables
-char**   args;
-FXbool dpkg = false;
-FXbool rpm = false;
-FXColor highlightcolor;
-FXbool allowPopupScroll = false;
-FXuint single_click;
-FXbool file_tooltips;
-FXbool relative_resize;
-FXbool save_win_pos;
+char** args;
 FXString homedir;
 FXString xdgconfighome;
 FXString xdgdatahome;
-FXbool xim_used = false;
+
+// Filter history
+char FilterHistory[FILTER_HIST_SIZE][MAX_PATTERN_SIZE];
+int FilterNum = 0;
+
+// Integer UI scaling factor
+FXint scaleint = 1;
 
 // Main window (not used but necessary for compilation)
 FXMainWindow* mainWindow = NULL;
 
-// Scaling factors for the UI
-extern double scalefrac;
 
 // Hand cursor replacement (integer scaling factor = 1)
 #define hand1_width     32
@@ -167,6 +163,7 @@ FXDEFMAP(XFilePackage) XFilePackageMap[] =
     FXMAPFUNC(SEL_COMMAND, XFilePackage::ID_ABOUT, XFilePackage::onCmdAbout),
     FXMAPFUNC(SEL_COMMAND, XFilePackage::ID_OPEN, XFilePackage::onCmdOpen),
     FXMAPFUNC(SEL_COMMAND, XFilePackage::ID_INSTALL, XFilePackage::onCmdInstall),
+    FXMAPFUNC(SEL_COMMAND, XFilePackage::ID_TAB, XFilePackage::onCmdTabClicked),
 };
 
 
@@ -174,15 +171,18 @@ FXDEFMAP(XFilePackage) XFilePackageMap[] =
 FXIMPLEMENT(XFilePackage, FXMainWindow, XFilePackageMap, ARRAYNUMBER(XFilePackageMap))
 
 // Constructor
-XFilePackage::XFilePackage(FXApp* a) : FXMainWindow(a, "Xfp", NULL, NULL, DECOR_ALL)
+XFilePackage::XFilePackage(FXApp* a) : FXMainWindow(a, "Xfp", NULL, NULL,
+                                                    DECOR_TITLE | DECOR_MINIMIZE | DECOR_MAXIMIZE | DECOR_CLOSE |
+                                                    DECOR_BORDER | DECOR_STRETCHABLE)
 {
     FXString key;
     FXHotKey hotkey;
 
+    // Application icon
     setIcon(xfpicon);
 
     // Make menu bar
-    menubar = new FXMenuBar(this, LAYOUT_DOCK_NEXT | LAYOUT_SIDE_TOP | LAYOUT_FILL_X | FRAME_RAISED);
+    menubar = new FXMenuBar(this, LAYOUT_DOCK_NEXT | LAYOUT_SIDE_TOP | LAYOUT_FILL_X | FRAME_NONE);
 
     // Sites where to dock
     FXDockSite* topdock = new FXDockSite(this, LAYOUT_SIDE_TOP | LAYOUT_FILL_X);
@@ -191,8 +191,9 @@ XFilePackage::XFilePackage(FXApp* a) : FXMainWindow(a, "Xfp", NULL, NULL, DECOR_
     new FXDockSite(this, LAYOUT_SIDE_RIGHT | LAYOUT_FILL_Y);
 
     // Tool bar
-    FXToolBarShell* dragshell1 = new FXToolBarShell(this, FRAME_RAISED);
-    toolbar = new FXToolBar(topdock, dragshell1, LAYOUT_DOCK_NEXT | LAYOUT_SIDE_TOP | LAYOUT_FILL_X | LAYOUT_FILL_Y | FRAME_RAISED);
+    FXToolBarShell* dragshell1 = new FXToolBarShell(this, FRAME_NONE);
+    toolbar = new FXToolBar(topdock, dragshell1,
+                            LAYOUT_DOCK_NEXT | LAYOUT_SIDE_TOP | LAYOUT_FILL_X | LAYOUT_FILL_Y | FRAME_NONE);
     new FXToolBarGrip(toolbar, toolbar, FXToolBar::ID_TOOLBARGRIP, TOOLBARGRIP_DOUBLE);
     int style = BUTTON_TOOLBAR;
 
@@ -210,21 +211,22 @@ XFilePackage::XFilePackage(FXApp* a) : FXMainWindow(a, "Xfp", NULL, NULL, DECOR_
 
     // Toolbar button: File open
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "open", "Ctrl-O");
-    new FXButton(toolbar, TAB + _("Open package file") + PARS(key), fileopenicon, this, ID_OPEN, style | FRAME_RAISED | LAYOUT_CENTER_Y | LAYOUT_LEFT);
+    new FXButton(toolbar, TAB + _("Open package file") + PARS(key), minifileopenicon, this, ID_OPEN,
+                 style | FRAME_NONE | LAYOUT_CENTER_Y | LAYOUT_LEFT);
 
     // File Menu entries
     FXMenuCommand* mc = NULL;
 
-    mc = new FXMenuCommand(filemenu, _("&Open..."), fileopenicon, this, ID_OPEN);
+    mc = new FXMenuCommand(filemenu, _("&Open..."), minifileopenicon, this, ID_OPEN);
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "open", "Ctrl-O");
     mc->setAccelText(key);
-    hotkey = _parseAccel(key);
+    hotkey = xf_parseaccel(key);
     getAccelTable()->addAccel(hotkey, mc, FXSEL(SEL_COMMAND, FXMenuCommand::ID_ACCEL));
 
-    mc = new FXMenuCommand(filemenu, _("&Quit"), quiticon, this, ID_QUIT);
+    mc = new FXMenuCommand(filemenu, _("&Quit"), miniquiticon, this, ID_QUIT);
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "quit", "Ctrl-Q");
     mc->setAccelText(key);
-    hotkey = _parseAccel(key);
+    hotkey = xf_parseaccel(key);
     getAccelTable()->addAccel(hotkey, mc, FXSEL(SEL_COMMAND, FXMenuCommand::ID_ACCEL));
     getAccelTable()->addAccel(KEY_Escape, this, FXSEL(SEL_COMMAND, ID_QUIT));
 
@@ -235,12 +237,12 @@ XFilePackage::XFilePackage(FXApp* a) : FXMainWindow(a, "Xfp", NULL, NULL, DECOR_
     mc = new FXMenuCommand(helpmenu, _("&About X File Package"), NULL, this, ID_ABOUT, 0);
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "help", "F1");
     mc->setAccelText(key);
-    hotkey = _parseAccel(key);
+    hotkey = xf_parseaccel(key);
     getAccelTable()->addAccel(hotkey, mc, FXSEL(SEL_COMMAND, FXMenuCommand::ID_ACCEL));
 
     // Close accelerator
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "close", "Ctrl-W");
-    hotkey = _parseAccel(key);
+    hotkey = xf_parseaccel(key);
     getAccelTable()->addAccel(hotkey, this, FXSEL(SEL_COMMAND, XFilePackage::ID_QUIT));
 
     // Make a tool tip
@@ -250,29 +252,34 @@ XFilePackage::XFilePackage(FXApp* a) : FXMainWindow(a, "Xfp", NULL, NULL, DECOR_
     FXHorizontalFrame* buttons = new FXHorizontalFrame(this, LAYOUT_SIDE_BOTTOM | LAYOUT_FILL_X);
     new FXDragCorner(buttons);
 
-    // Close
-    new FXButton(buttons, _("&Close"), NULL, this, XFilePackage::ID_QUIT, FRAME_RAISED | FRAME_THICK | LAYOUT_RIGHT | LAYOUT_CENTER_Y, 0, 0, 0, 0, 20, 20);
+    // Quit
+    new FXButton(buttons, _("&Quit"), NULL, this, XFilePackage::ID_QUIT, FRAME_GROOVE | LAYOUT_RIGHT | LAYOUT_CENTER_Y,
+                 0, 0, 0, 0, 20, 20);
 
     // Uninstall
-    new FXButton(buttons, _("&Uninstall"), NULL, this, XFilePackage::ID_UNINSTALL, FRAME_RAISED | FRAME_THICK | LAYOUT_RIGHT | LAYOUT_CENTER_Y, 0, 0, 0, 0, 20, 20);
+    new FXButton(buttons, _("&Uninstall"), NULL, this, XFilePackage::ID_UNINSTALL,
+                 FRAME_GROOVE | LAYOUT_RIGHT | LAYOUT_CENTER_Y, 0, 0, 0, 0, 20, 20);
 
     // Install/Upgrade
-    new FXButton(buttons, _("&Install/Upgrade"), NULL, this, XFilePackage::ID_INSTALL, FRAME_RAISED | FRAME_THICK | LAYOUT_RIGHT | LAYOUT_CENTER_Y, 0, 0, 0, 0, 20, 20);
+    new FXButton(buttons, _("&Install/Upgrade"), NULL, this, XFilePackage::ID_INSTALL,
+                 FRAME_GROOVE | LAYOUT_RIGHT | LAYOUT_CENTER_Y, 0, 0, 0, 0, 20, 20);
 
     // Switcher
-    FXTabBook* tabbook = new FXTabBook(this, NULL, 0, LAYOUT_FILL_X | LAYOUT_FILL_Y | LAYOUT_RIGHT | FRAME_RAISED, 0, 0, 0, 0, 0, 0, 0, 0);
+    tabbook = new FXTabBook(this, this, ID_TAB, LAYOUT_FILL_X | LAYOUT_FILL_Y | LAYOUT_RIGHT | FRAME_NONE, 0, 0, 0, 0,
+                            0, 0, 0, 0);
 
-    // First item is Description
+    // First tab is Description
     new FXTabItem(tabbook, _("&Description"), NULL);
     FXVerticalFrame* descr = new FXVerticalFrame(tabbook);
-    FXPacker*        p = new FXPacker(descr, LAYOUT_FILL_X | LAYOUT_FILL_Y | FRAME_SUNKEN, 0, 0, 0, 0, 0, 0, 0, 0);
+    FXPacker* p = new FXPacker(descr, LAYOUT_FILL_X | LAYOUT_FILL_Y | FRAME_NONE, 0, 0, 0, 0, 0, 0, 0, 0);
     description = new FXText(p, this, XFilePackage::ID_DESCRIPTION, LAYOUT_FILL_X | LAYOUT_FILL_Y);
 
-    // Second item is File List
+    // Second tab is File List
     new FXTabItem(tabbook, _("File &List"), NULL);
     FXVerticalFrame* flistfr = new FXVerticalFrame(tabbook);
-    p = new FXPacker(flistfr, LAYOUT_FILL_X | LAYOUT_FILL_Y | FRAME_SUNKEN, 0, 0, 0, 0, 0, 0, 0, 0);
-    list = new FXTreeList(p, this, XFilePackage::ID_FILELIST, LAYOUT_FILL_X | LAYOUT_FILL_Y | TREELIST_SHOWS_LINES);
+    p = new FXPacker(flistfr, LAYOUT_FILL_X | LAYOUT_FILL_Y | FRAME_NONE, 0, 0, 0, 0, 0, 0, 0, 0);
+    list = new FXTreeList(p, this, XFilePackage::IDFILELIST,
+                          LAYOUT_FILL_X | LAYOUT_FILL_Y | TREELIST_SHOWS_LINES | TREELIST_SINGLESELECT);
 
     // Initialize file name
     filename = "";
@@ -280,6 +287,9 @@ XFilePackage::XFilePackage(FXApp* a) : FXMainWindow(a, "Xfp", NULL, NULL, DECOR_
     // Other initializations
     smoothscroll = true;
     errorflag = false;
+
+    // Read settings
+    save_win_pos = getApp()->reg().readUnsignedEntry("SETTINGS", "save_win_pos", false);
 }
 
 
@@ -293,6 +303,7 @@ XFilePackage::~XFilePackage()
     delete helpmenu;
     delete list;
     delete description;
+    delete tabbook;
 }
 
 
@@ -304,9 +315,10 @@ long XFilePackage::onCmdAbout(FXObject*, FXSelector, void*)
     msg.format(_("X File Package Version %s is a simple rpm or deb package manager.\n\n"), VERSION);
     msg += COPYRIGHT;
     MessageBox about(this, _("About X File Package"), msg.text(), xfpicon, BOX_OK | DECOR_TITLE | DECOR_BORDER,
-                     JUSTIFY_CENTER_X | ICON_BEFORE_TEXT | LAYOUT_CENTER_Y | LAYOUT_LEFT | LAYOUT_FILL_X | LAYOUT_FILL_Y);
+                     JUSTIFY_CENTER_X | ICON_BEFORE_TEXT | LAYOUT_CENTER_Y | LAYOUT_LEFT | LAYOUT_FILL_X |
+                     LAYOUT_FILL_Y);
     about.execute(PLACEMENT_OWNER);
-    return(1);
+    return 1;
 }
 
 
@@ -322,19 +334,20 @@ long XFilePackage::onCmdOpen(FXObject*, FXSelector, void*)
         NULL
     };
 
+    errorflag = false;
     FileDialog opendialog(this, _("Open Document"));
 
     opendialog.setSelectMode(SELECTFILE_EXISTING);
     opendialog.setPatternList(patterns);
     opendialog.setDirectory(FXPath::directory(filename));
-    if (opendialog.execute())
+    if (opendialog.execute(PLACEMENT_OWNER))
     {
         filename = opendialog.getFilename();
         readDescription();
         readFileList();
     }
 
-    return(1);
+    return 1;
 }
 
 
@@ -348,7 +361,7 @@ long XFilePackage::onCmdInstall(FXObject*, FXSelector, void*)
     if (strlen(filename.text()) == 0)
     {
         MessageBox::error(this, BOX_OK, _("Error"), _("No package loaded"));
-        return(0);
+        return 0;
     }
 
     // Package name
@@ -367,7 +380,7 @@ long XFilePackage::onCmdInstall(FXObject*, FXSelector, void*)
     else
     {
         MessageBox::error(this, BOX_OK, _("Error"), _("Unknown package format"));
-        return(0);
+        return 0;
     }
 
     // Make and show command window
@@ -380,7 +393,7 @@ long XFilePackage::onCmdInstall(FXObject*, FXSelector, void*)
 
     // The CommandWindow object will delete itself when closed!
 
-    return(1);
+    return 1;
 }
 
 
@@ -394,7 +407,7 @@ long XFilePackage::onCmdUninstall(FXObject*, FXSelector, void*)
     if (strlen(filename.text()) == 0)
     {
         MessageBox::error(this, BOX_OK, _("Error"), _("No package loaded"));
-        return(0);
+        return 0;
     }
 
     // Command to perform
@@ -417,7 +430,7 @@ long XFilePackage::onCmdUninstall(FXObject*, FXSelector, void*)
     else
     {
         MessageBox::error(this, BOX_OK, _("Error"), _("Unknown package format"));
-        return(0);
+        return 0;
     }
 
     // Make and show command window
@@ -430,7 +443,7 @@ long XFilePackage::onCmdUninstall(FXObject*, FXSelector, void*)
 
     // The CommandWindow object will delete itself when closed!
 
-    return(1);
+    return 1;
 }
 
 
@@ -470,6 +483,18 @@ void XFilePackage::saveConfig()
         getApp()->reg().writeUnsignedEntry("OPTIONS", "showtoolbar", false);
     }
 
+    // Write filter history
+    FXString history = "";
+    for (int i = 0; i < FilterNum; i++)
+    {
+        history += FilterHistory[i];
+        history += ":";
+    }
+    if (FilterNum)
+    {
+        getApp()->reg().writeStringEntry("HISTORY", "filter", history.text());
+    }
+
     // Write registry options
     getApp()->reg().write();
 }
@@ -479,8 +504,9 @@ void XFilePackage::saveConfig()
 long XFilePackage::onSigHarvest(FXObject*, FXSelector, void*)
 {
     while (waitpid(-1, NULL, WNOHANG) > 0)
-    {}
-    return(1);
+    {
+    }
+    return 1;
 }
 
 
@@ -492,11 +518,22 @@ long XFilePackage::onCmdQuit(FXObject*, FXSelector, void*)
 
     // Exit
     getApp()->exit(EXIT_SUCCESS);
-    return(1);
+    return 1;
 }
 
 
-// Update file list
+// Refresh tabs
+long XFilePackage::onCmdTabClicked(FXObject*, FXSelector, void*)
+{
+    description->recalc();
+    list->recalc();
+
+    return 1;
+}
+
+
+
+// Read package file list
 int XFilePackage::readFileList(void)
 {
     FXString cmd;
@@ -506,19 +543,19 @@ int XFilePackage::readFileList(void)
     if (comparecase(ext, "rpm") == 0)
     {
         errorflag = false;
-        cmd = "rpm -qlp " + ::quote(filename);
+        cmd = "rpm -qlp " + xf_quote(filename);
     }
     else if (comparecase(ext, "deb") == 0)
     {
         errorflag = false;
-        cmd = "dpkg -c " + ::quote(filename);
+        cmd = "dpkg -c " + xf_quote(filename);
     }
     else if (errorflag == false)
     {
         errorflag = true;
         list->clearItems();
         MessageBox::error(this, BOX_OK, _("Error"), _("Unknown package format"));
-        return(0);
+        return 0;
     }
 
     FILE* pcmd = popen(cmd.text(), "r");
@@ -530,7 +567,7 @@ int XFilePackage::readFileList(void)
     char text[10000] = { 0 };
     FXString str;
     str = FXPath::name(filename);
-    strlcpy_(text, str.text(), str.length() + 1);
+    xf_strlcpy(text, str.text(), str.length() + 1);
 
     // Clear list
     list->clearItems();
@@ -554,10 +591,11 @@ int XFilePackage::readFileList(void)
     getApp()->endWaitCursor();
 
     pclose(pcmd);
-    return(1);
+    return 1;
 }
 
 
+// Read package description
 int XFilePackage::readDescription(void)
 {
     FXString cmd;
@@ -568,21 +606,21 @@ int XFilePackage::readDescription(void)
     if (comparecase(ext, "rpm") == 0)
     {
         errorflag = false;
-        cmd = "rpm -qip " + ::quote(filename);
+        cmd = "rpm -qip " + xf_quote(filename);
         buf += _("[RPM package]\n");
     }
     else if (comparecase(ext, "deb") == 0)
     {
         errorflag = false;
         buf += _("[DEB package]\n");
-        cmd = "dpkg -I " + ::quote(filename);
+        cmd = "dpkg -I " + xf_quote(filename);
     }
     else if (errorflag == false)
     {
         errorflag = true;
         list->clearItems();
         MessageBox::error(this, BOX_OK, _("Error"), _("Unknown package format"));
-        return(0);
+        return 0;
     }
 
     FILE* pcmd = popen(cmd.text(), "r");
@@ -611,7 +649,7 @@ int XFilePackage::readDescription(void)
             buf += text;
         }
     }
-    if ((pclose(pcmd) == -1) && (errno != ECHILD))  // ECHILD can be set if the child was caught by sigHarvest
+    if ((pclose(pcmd) == -1) && (errno != ECHILD)) // ECHILD can be set if the child was caught by sigHarvest
     {
         MessageBox::error(this, BOX_OK, _("Error"), _("Query of %s failed!"), filename.text());
         list->clearItems();
@@ -623,11 +661,11 @@ int XFilePackage::readDescription(void)
         description->setText(buf.text());
     }
 
-    return(1);
+    return 1;
 }
 
 
-// Start the ball rolling
+// Start application
 void XFilePackage::start(FXString startpkg)
 {
     filename = startpkg;
@@ -695,9 +733,34 @@ void XFilePackage::create()
         position(getX(), getY(), width, height);
     }
 
+    // Read filter history
+    FXString history = getApp()->reg().readStringEntry("HISTORY", "filter", "");
+    FXString histent = "";
+    FilterNum = 0;
+    if (history != "")
+    {
+        int i;
+        for (i = 0; ; i++)
+        {
+            if (i < FILTER_HIST_SIZE)
+            {
+                histent = history.section(':', i);
+                if (xf_strequal(histent.text(), ""))
+                {
+                    break;
+                }
+                xf_strlcpy(FilterHistory[i], histent.text(), histent.length() + 1);
+            }
+            else
+            {
+                break;
+            }
+        }
+        FilterNum = i;
+    }
+
     FXMainWindow::create();
 
-    // This is necessary otherwise Xfp crashes when opening a package, but why?
     minifoldericon->create();
     minifolderopenicon->create();
     minidocicon->create();
@@ -715,7 +778,8 @@ void XFilePackage::create()
 
 
 // Usage message
-#define USAGE_MSG    _("\
+#define USAGE_MSG    _( \
+            "\
 \nUsage: xfp [options] [package] \n\
 \n\
     [options] can be any of the following:\n\
@@ -756,17 +820,6 @@ int main(int argc, char* argv[])
         xdgconfighome = homedir + PATHSEPSTRING CONFIGPATH;
     }
 
-    // Detect if an X input method is used
-    xmodifiers = getenv("XMODIFIERS");
-    if ((xmodifiers == "") || (xmodifiers == "@im=none"))
-    {
-        xim_used = false;
-    }
-    else
-    {
-        xim_used = true;
-    }
-
 #ifdef HAVE_SETLOCALE
     // Set locale via LC_ALL.
     setlocale(LC_ALL, "");
@@ -816,21 +869,23 @@ int main(int argc, char* argv[])
     // Compute integer and fractional scaling factors depending on the monitor resolution
     FXint res = reg_xfe->readUnsignedEntry("SETTINGS", "screenres", 100);
     scaleint = round(res / 100.0);
-    scalefrac = FXMAX(1.0, res / 100.0);
 
     // Redefine the default hand cursor depending on the integer scaling factor
     FXCursor* hand;
     if (scaleint == 1)
     {
-        hand = new FXCursor(application, hand1_bits, hand1_mask_bits, hand1_width, hand1_height, hand1_x_hot, hand1_y_hot);
+        hand = new FXCursor(application, hand1_bits, hand1_mask_bits, hand1_width, hand1_height, hand1_x_hot,
+                            hand1_y_hot);
     }
     else if (scaleint == 2)
     {
-        hand = new FXCursor(application, hand2_bits, hand2_mask_bits, hand2_width, hand2_height, hand2_x_hot, hand2_y_hot);
+        hand = new FXCursor(application, hand2_bits, hand2_mask_bits, hand2_width, hand2_height, hand2_x_hot,
+                            hand2_y_hot);
     }
     else
     {
-        hand = new FXCursor(application, hand3_bits, hand3_mask_bits, hand3_width, hand3_height, hand3_x_hot, hand3_y_hot);
+        hand = new FXCursor(application, hand3_bits, hand3_mask_bits, hand3_width, hand3_height, hand3_x_hot,
+                            hand3_y_hot);
     }
     application->setDefaultCursor(DEF_HAND_CURSOR, hand);
 
@@ -838,9 +893,11 @@ int main(int argc, char* argv[])
     FXbool iconpathfound = true;
     loadicons = loadAppIcons(application, &iconpathfound);
 
-    // Set base color (to change the default base color at first run)
-    FXColor basecolor = reg_xfe->readColorEntry("SETTINGS", "basecolor", FXRGB(237, 233, 227));
+    // Set base and border colors (to change the default colors at first run)
+    FXColor basecolor = reg_xfe->readColorEntry("SETTINGS", "basecolor", FXRGB(237, 236, 235));
+    FXColor bordercolor = reg_xfe->readColorEntry("SETTINGS", "bordercolor", FXRGB(125, 125, 125));
     application->setBaseColor(basecolor);
+    application->setBorderColor(bordercolor);
 
     // Set Xfp normal font according to the Xfe registry
     FXString fontspec;
@@ -853,19 +910,23 @@ int main(int argc, char* argv[])
     }
 
     // Set single click navigation according to the Xfe registry
-    single_click = reg_xfe->readUnsignedEntry("SETTINGS", "single_click", SINGLE_CLICK_NONE);
+    FXuint single_click = reg_xfe->readUnsignedEntry("SETTINGS", "single_click", SINGLE_CLICK_NONE);
+    application->reg().writeUnsignedEntry("SETTINGS", "single_click", single_click);
 
     // Set smooth scrolling according to the Xfe registry
     FXbool smoothscroll = reg_xfe->readUnsignedEntry("SETTINGS", "smooth_scroll", true);
 
     // Set file list tooltip flag according to the Xfe registry
-    file_tooltips = reg_xfe->readUnsignedEntry("SETTINGS", "file_tooltips", true);
+    FXbool file_tooltips = reg_xfe->readUnsignedEntry("SETTINGS", "file_tooltips", true);
+    application->reg().writeUnsignedEntry("SETTINGS", "file_tooltips", file_tooltips);
 
     // Set relative resizing flag according to the Xfe registry
-    relative_resize = reg_xfe->readUnsignedEntry("SETTINGS", "relative_resize", true);
+    FXbool relative_resize = reg_xfe->readUnsignedEntry("SETTINGS", "relative_resize", true);
+    application->reg().writeUnsignedEntry("SETTINGS", "relative_resize", relative_resize);
 
     // Get value of the window position flag
-    save_win_pos = reg_xfe->readUnsignedEntry("SETTINGS", "save_win_pos", false);
+    FXbool save_win_pos = reg_xfe->readUnsignedEntry("SETTINGS", "save_win_pos", false);
+    application->reg().writeUnsignedEntry("SETTINGS", "save_win_pos", save_win_pos);
 
     // Delete the Xfe registry
     delete reg_xfe;
@@ -885,13 +946,15 @@ int main(int argc, char* argv[])
     // Icon path not found
     if (!iconpathfound)
     {
-        MessageBox::error(application, BOX_OK, _("Error loading icons"), _("Icon path doesn't exist, icon theme was set back to default. Please check your icon path!") );
+        MessageBox::error(application, BOX_OK, _("Error loading icons"),
+                          _("Icon path doesn't exist, icon theme was set back to default. Please check your icon path!"));
     }
 
     // Some icons not found
     if (!loadicons)
     {
-        MessageBox::error(application, BOX_OK, _("Error loading icons"), _("Unable to load some icons. Please check your icon theme!"));
+        MessageBox::error(application, BOX_OK, _("Error loading icons"),
+                          _("Unable to load some icons. Please check your icon theme!"));
     }
 
     // Tooltips setup time and duration
@@ -901,16 +964,18 @@ int main(int argc, char* argv[])
     // Test the existence of the Debian package manager (dpkg)
     // and the RedHat package manager (rpm)
     FXString cmd = "dpkg --version";
-    FXString str = getCommandOutput(cmd);
+    FXString str = xf_getcommandoutput(cmd);
 
+    FXbool dpkg = false;
     if (str.find("Debian") != -1)
     {
         dpkg = true;
     }
 
     cmd = "rpm --version";
-    str = getCommandOutput(cmd);
+    str = xf_getcommandoutput(cmd);
 
+    FXbool rpm = false;
     if (str.find("RPM") != -1)
     {
         rpm = true;
@@ -927,5 +992,5 @@ int main(int argc, char* argv[])
     window->start(startpkg);
 
     // Run the application
-    return(application->run());
+    return application->run();
 }
